@@ -10,6 +10,33 @@ import handle
 _moduleLogger = logging.getLogger('aliasing')
 
 
+def _make_pretty_with_areacodde(phonenumber):
+	prettynumber = "(%s)" % (phonenumber[0:3], )
+	if 3 < len(phonenumber):
+		prettynumber += " %s" % (phonenumber[3:6], )
+		if 6 < len(phonenumber):
+			prettynumber += "-%s" % (phonenumber[6:], )
+	return prettynumber
+
+
+def _make_pretty_local(phonenumber):
+	prettynumber = "%s" % (phonenumber[0:3], )
+	if 3 < len(phonenumber):
+		prettynumber += "-%s" % (phonenumber[3:], )
+	return prettynumber
+
+
+def _make_pretty_international(phonenumber):
+	if phonenumber.startswith("0"):
+		prettynumber = "+%s " % (phonenumber[0:3], )
+		if 3 < len(phonenumber):
+			prettynumber += _make_pretty_with_areacodde(phonenumber[3:])
+	if phonenumber.startswith("1"):
+		prettynumber = "1 "
+		prettynumber += _make_pretty_with_areacodde(phonenumber[1:])
+	return prettynumber
+
+
 def make_pretty(phonenumber):
 	"""
 	Function to take a phone number and return the pretty version
@@ -27,37 +54,38 @@ def make_pretty(phonenumber):
 	>>> make_pretty("1234567")
 	'123-4567'
 	>>> make_pretty("2345678901")
-	'(234)-567-8901'
+	'(234) 567-8901'
 	>>> make_pretty("12345678901")
-	'1 (234)-567-8901'
+	'1 (234) 567-8901'
 	>>> make_pretty("01234567890")
-	'+012-(345)-678-90'
+	'+012 (345) 678-90'
+	>>> make_pretty("+01234567890")
+	'+012 (345) 678-90'
+	>>> make_pretty("+12")
+	'+1 (2)'
+	>>> make_pretty("+123")
+	'+1 (23)'
+	>>> make_pretty("+1234")
+	'+1 (234)'
 	"""
 	if phonenumber is None or phonenumber is "":
 		return ""
 
 	phonenumber = util_misc.strip_number(phonenumber)
 
-	if len(phonenumber) < 3:
-		return phonenumber
-
-	if phonenumber[0] == "0":
-		prettynumber = ""
-		prettynumber += "+%s" % phonenumber[0:3]
-		if 3 < len(phonenumber):
-			prettynumber += "-(%s)" % phonenumber[3:6]
-			if 6 < len(phonenumber):
-				prettynumber += "-%s" % phonenumber[6:9]
-				if 9 < len(phonenumber):
-					prettynumber += "-%s" % phonenumber[9:]
-		return prettynumber
-	elif len(phonenumber) <= 7:
-		prettynumber = "%s-%s" % (phonenumber[0:3], phonenumber[3:])
-	elif len(phonenumber) > 8 and phonenumber[0] == "1":
-		prettynumber = "1 (%s)-%s-%s" % (phonenumber[1:4], phonenumber[4:7], phonenumber[7:])
-	elif len(phonenumber) > 7:
-		prettynumber = "(%s)-%s-%s" % (phonenumber[0:3], phonenumber[3:6], phonenumber[6:])
-	return prettynumber
+	if phonenumber[0] == "+":
+		prettynumber = _make_pretty_international(phonenumber[1:])
+		if not prettynumber.startswith("+"):
+			prettynumber = "+"+prettynumber
+	elif 8 < len(phonenumber) and phonenumber[0] in ("0", "1"):
+		prettynumber = _make_pretty_international(phonenumber)
+	elif 7 < len(phonenumber):
+		prettynumber = _make_pretty_with_areacodde(phonenumber)
+	elif 3 < len(phonenumber):
+		prettynumber = _make_pretty_local(phonenumber)
+	else:
+		prettynumber = phonenumber
+	return prettynumber.strip()
 
 
 class AliasingMixin(telepathy.server.ConnectionInterfaceAliasing):
